@@ -4,9 +4,23 @@ import logging
 import attr
 
 from .const import (
+    CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    CONCENTRATION_PARTS_PER_BILLION,
+    CONCENTRATION_PARTS_PER_MILLION,
     CONF_DEVICENAME,
     CONF_MAC,
     CONF_SENSOR,
+    ELECTRICAL_CURRENT_AMPERE,
+    ELECTRICAL_VOLT_AMPERE,
+    ENERGY_KILO_WATT_HOUR,
+    FREQUENCY_HERTZ,
+    LENGTH_CENTIMETERS,
+    LIGHT_LUX,
+    MASS_KILOGRAMS,
+    PERCENTAGE,
+    POWER_WATT,
+    PRESSURE_HPA,
+    PRESSURE_MMHG,
     SENSOR_AMBIENT,
     SENSOR_APPARENT_POWERUSAGE,
     SENSOR_BATTERY,
@@ -50,6 +64,16 @@ from .const import (
     SENSOR_VOLTAGE,
     SENSOR_WEIGHT,
     SENSOR_YESTERDAY,
+    SPEED_FEET_PER_SECOND,
+    SPEED_KILOMETERS_PER_HOUR,
+    SPEED_KNOT,
+    SPEED_METERS_PER_SECOND,
+    SPEED_MILES_PER_HOUR,
+    SPEED_YARDS_PER_SECOND,
+    TEMP_CELSIUS,
+    TEMP_FAHRENHEIT,
+    TEMP_KELVIN,
+    VOLT,
 )
 from .entity import (
     TasmotaAvailability,
@@ -112,49 +136,60 @@ IGNORED_SENSORS = ["Time", "PN532", "RDM6300"]
 
 
 SENSOR_UNIT_MAP = {
-    SENSOR_APPARENT_POWERUSAGE: "VA",
-    SENSOR_BATTERY: "%",
-    SENSOR_CURRENT: "A",
-    SENSOR_DISTANCE: "cm",
-    SENSOR_FREQUENCY: "Hz",
-    SENSOR_HUMIDITY: "%",
-    SENSOR_ILLUMINANCE: "lux",
-    SENSOR_MOISTURE: "%",
+    SENSOR_APPARENT_POWERUSAGE: ELECTRICAL_VOLT_AMPERE,
+    SENSOR_BATTERY: PERCENTAGE,
+    SENSOR_CURRENT: ELECTRICAL_CURRENT_AMPERE,
+    SENSOR_DISTANCE: LENGTH_CENTIMETERS,
+    SENSOR_FREQUENCY: FREQUENCY_HERTZ,
+    SENSOR_HUMIDITY: PERCENTAGE,
+    SENSOR_ILLUMINANCE: LIGHT_LUX,
+    SENSOR_MOISTURE: PERCENTAGE,
     SENSOR_PB0_3: "ppd",
     SENSOR_PB0_5: "ppd",
     SENSOR_PB1: "ppd",
     SENSOR_PB2_5: "ppd",
     SENSOR_PB5: "ppd",
     SENSOR_PB10: "ppd",
-    SENSOR_PM1: "µg/m³",
-    SENSOR_PM2_5: "µg/m³",
-    SENSOR_PM10: "µg/m³",
+    SENSOR_PM1: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_PM2_5: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+    SENSOR_PM10: CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
     SENSOR_POWERFACTOR: "Cos φ",
-    SENSOR_POWERUSAGE: "W",
+    SENSOR_POWERUSAGE: POWER_WATT,
     SENSOR_TOTAL_START_TIME: " ",
     SENSOR_REACTIVE_POWERUSAGE: "VAr",
-    SENSOR_TODAY: "kWh",
-    SENSOR_TOTAL: "kWh",
-    SENSOR_VOLTAGE: "V",
-    SENSOR_WEIGHT: "kg",
-    SENSOR_YESTERDAY: "kWh",
-    SENSOR_CO2: "ppm",
-    SENSOR_ECO2: "ppm",
-    SENSOR_TVOC: "ppb",
+    SENSOR_TODAY: ENERGY_KILO_WATT_HOUR,
+    SENSOR_TOTAL: ENERGY_KILO_WATT_HOUR,
+    SENSOR_VOLTAGE: VOLT,
+    SENSOR_WEIGHT: MASS_KILOGRAMS,
+    SENSOR_YESTERDAY: ENERGY_KILO_WATT_HOUR,
+    SENSOR_CO2: CONCENTRATION_PARTS_PER_MILLION,
+    SENSOR_ECO2: CONCENTRATION_PARTS_PER_MILLION,
+    SENSOR_TVOC: CONCENTRATION_PARTS_PER_BILLION,
     SENSOR_COLOR_RED: "R",
     SENSOR_COLOR_GREEN: "G",
     SENSOR_COLOR_BLUE: "B",
-    SENSOR_CCT: "K",
+    SENSOR_CCT: TEMP_KELVIN,
     SENSOR_PROXIMITY: " ",
-    SENSOR_AMBIENT: "lux",
+    SENSOR_AMBIENT: LIGHT_LUX,
 }
 
+SUPPORTED_PRESSURE_UNITS = [PRESSURE_HPA, PRESSURE_MMHG]
+SUPPORTED_SPEED_UNITS = [
+    SPEED_METERS_PER_SECOND,
+    SPEED_KILOMETERS_PER_HOUR,
+    SPEED_KNOT,
+    SPEED_MILES_PER_HOUR,
+    SPEED_FEET_PER_SECOND,
+    SPEED_YARDS_PER_SECOND,
+]
+SUPPORTED_TEMPERATURE_UNITS = [TEMP_CELSIUS, TEMP_FAHRENHEIT]
+
 SENSOR_DYNAMIC_UNIT_MAP = {
-    SENSOR_DEWPOINT: SENSOR_UNIT_TEMPERATURE,
-    SENSOR_PRESSURE: SENSOR_UNIT_PRESSURE,
-    SENSOR_PRESSUREATSEALEVEL: SENSOR_UNIT_PRESSURE,
-    SENSOR_SPEED: SENSOR_UNIT_SPEED,
-    SENSOR_TEMPERATURE: SENSOR_UNIT_TEMPERATURE,
+    SENSOR_DEWPOINT: (SENSOR_UNIT_TEMPERATURE, SUPPORTED_TEMPERATURE_UNITS),
+    SENSOR_PRESSURE: (SENSOR_UNIT_PRESSURE, SUPPORTED_PRESSURE_UNITS),
+    SENSOR_PRESSUREATSEALEVEL: (SENSOR_UNIT_PRESSURE, SUPPORTED_PRESSURE_UNITS),
+    SENSOR_SPEED: (SENSOR_UNIT_SPEED, SUPPORTED_SPEED_UNITS),
+    SENSOR_TEMPERATURE: (SENSOR_UNIT_TEMPERATURE, SUPPORTED_TEMPERATURE_UNITS),
 }
 
 _LOGGER = logging.getLogger(__name__)
@@ -162,7 +197,7 @@ _LOGGER = logging.getLogger(__name__)
 
 @attr.s(slots=True, frozen=True)
 class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
-    """Tasmota switch configuation."""
+    """Tasmota Status Sensor configuration."""
 
     poll_topic: str = attr.ib()
     quantity: str = attr.ib()
@@ -178,7 +213,10 @@ class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
         """Instantiate from discovery message."""
         unit = SENSOR_UNIT_MAP.get(quantity, " ")
         if quantity in SENSOR_DYNAMIC_UNIT_MAP:
-            unit = sensor_config[CONF_SENSOR].get(SENSOR_DYNAMIC_UNIT_MAP[quantity])
+            key, supported_units = SENSOR_DYNAMIC_UNIT_MAP[quantity]
+            unit = sensor_config[CONF_SENSOR].get(key)
+            if unit not in supported_units:
+                _LOGGER.warning("Unknown unit %s for %s", unit, quantity)
 
         return cls(
             endpoint="sensor",
@@ -206,7 +244,7 @@ class TasmotaSensorConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
 
 
 class TasmotaSensor(TasmotaAvailability, TasmotaEntity):
-    """Representation of a Tasmota switch."""
+    """Representation of Tasmota Status Sensors."""
 
     def __init__(self, **kwds):
         """Initialize."""
@@ -234,7 +272,7 @@ class TasmotaSensor(TasmotaAvailability, TasmotaEntity):
                 "topic": self._cfg.state_topic1,
                 "msg_callback": state_message_received,
             },
-            # Polled state update (stat/STATUS8)
+            # Polled state update (stat/STATUS10)
             "state_topic2": {
                 "event_loop_safe": True,
                 "topic": self._cfg.state_topic2,
